@@ -88,6 +88,96 @@ static int option_count = sizeof(option_list)/sizeof(t_option);
            *    Functions    *
 			   ***/
 
+/* Returns value of environment variable XDG_DATA_HOME when defined,
+ * otherwise, returns the default $HOME/.local/share, unless if HOME
+ * is not set in which case NULL is returned.
+ *
+ * It is up to the caller to free the memory used by the returned string.
+ */
+static char *get_xdg_data_home() {
+  char *var=NULL;
+
+  if ( (var=getenv("XDG_DATA_HOME")) && (strlen(var)>0) ) {
+    return strdup(var);
+  }
+
+  if ( (var=getenv("HOME")) && (strlen(var)>0) ) {
+    return strdup("$HOME/.local/share");
+  }
+
+  return NULL;
+}
+
+/* Returns value of environment variable XDG_DATA_DIRS when defined, the
+ * default, ie. /usr/local/share:/usr/share, otherwise.
+ *
+ * It is up to the caller to free the memory used by the returned string.
+ */
+static char *get_xdg_data_dirs() {
+  char *str = NULL;
+
+  if ( (str=getenv("XDG_DATA_DIRS")) && (strlen(str)>0) ) {
+    return strdup(str);
+  }
+
+  return strdup("/usr/local/share:/usr/share");
+}
+
+/* Returns the desktop files search path as a colon separated list of
+ * path and according to the environment variables XDG_DATA_HOME and 
+ * XDG_DATA_DIRS.
+ *
+ * It is up to the caller to free the memory used by the returned string.
+ * 
+ * see https://specifications.freedesktop.org/basedir-spec/basedir-spec-latest.html
+ */
+static char *get_xdg_desktop_file_search_path() {
+  char *app_folder    = "/applications";
+  char *xdg_var[]     = { get_xdg_data_home(), get_xdg_data_dirs() } ;
+  int   xdg_var_count = sizeof(xdg_var)/sizeof(char*);
+
+  char *path          = NULL;
+  char *stok_saveptr  = NULL;
+  char *token         = NULL;
+  int   len           = 0;
+
+  /* Creates the desktop files search path (colon separated list) from
+   * the path lists specified by environment variables XDG_DATA_HOME
+   * and XDG_DATA_DIRS.
+   *
+   * For each path P in these variables, there must be a corresponding 
+   * path P'="P/applications" in the returned path list.
+   */
+
+  for (int i=0;i<xdg_var_count;i++) {
+    if (!xdg_var[i]) {
+      continue ;
+    }
+
+    stok_saveptr = NULL;
+    token        = strtok_r(xdg_var[i],":",&stok_saveptr);
+
+    while (token) {
+
+      len+=strlen(token)+strlen(app_folder);
+      
+      if (!path) {
+	path=calloc(len+1,sizeof(char));
+      } else {
+	len++;
+	path=realloc(path,(len+1)*sizeof(char));
+	strcat(path,":");
+      }
+      strcat(path,token);
+      strcat(path,app_folder);
+      token=strtok_r(NULL,":",&stok_saveptr);
+    }
+    free(xdg_var[i]);
+  }
+
+  return path;
+}
+
 /* Creates and returns a new *t_frame
  */
 static t_frame *new_frame(char *hicolor, 
@@ -337,9 +427,11 @@ t_config *create_config() {
     return config;
   }
 
+  char *dtfile_search_path=get_xdg_desktop_file_search_path();
+
   /* The WMAL_xxx and DEFAULT_xxxx "constants" are defined in config.h.in
    */
-  
+
   config=malloc(sizeof(t_config));
 
   config->command                = NULL;
@@ -360,7 +452,7 @@ t_config *create_config() {
   config->hover_border_color     = strdup(DEFAULT_HOVER_BORDER_COLOR);
     
   config->icon_search_path         = str_to_path_list(WMAL_ICON_SEARCH_PATH,WMAL_MAIN_ROOT_ICON_SEARCH_PATH);
-  config->desktop_file_search_path = str_to_path_list(WMAL_DESKTOP_FILE_SEARCH_PATH,NULL);
+  config->desktop_file_search_path = str_to_path_list(dtfile_search_path,NULL);
   config->font_search_path         = str_to_path_list(WMAL_FONT_SEARCH_PATH,NULL);
   
   config->tooltip_text           = NULL;
@@ -397,6 +489,8 @@ t_config *create_config() {
   config->exit_on_rclick	 = false;
 
   update_icon_size(NULL_OPTION,"create_config");
+
+  free(dtfile_search_path);
     
   return config;
 }
@@ -649,7 +743,8 @@ void set_config_field(t_option_id option_id, void *value) {
   char  opt_name1[32];
   char *temp;
   char *endptr;
-  char *stok_saveptr;
+  char *wstr;
+  char *stok_saveptr = NULL;
   int   pos;
   int   len;
   bool  flag;
@@ -776,30 +871,36 @@ Must be an integer in range [%d..%d]. Default to: %d.\n"),
     
     
     case ICON_SEARCH_PATH:
-      temp=strtok_r(strval,":",&stok_saveptr);
+      wstr=strdup(strval);
+      temp=strtok_r(wstr,":",&stok_saveptr);
       pos=0;
       while (temp) {
 	add_path(config->icon_search_path,temp,WMAL_MAIN_ROOT_ICON_SEARCH_PATH,pos++);
 	temp=strtok_r(NULL,":",&stok_saveptr);
       }
+      free(wstr);
     break;
     
     case DESKTOP_FILE_SEARCH_PATH:
-      temp=strtok_r(strval,":",&stok_saveptr);
+      wstr=strdup(strval);
+      temp=strtok_r(wstr,":",&stok_saveptr);
       pos=0;
       while (temp) {
 	add_path(config->desktop_file_search_path,temp,NULL,pos++);
 	temp=strtok_r(NULL,":",&stok_saveptr);
       }
+      free(wstr);
     break;
 
     case FONT_SEARCH_PATH:
-      temp=strtok_r(strval,":",&stok_saveptr);
+      wstr=strdup(strval);
+      temp=strtok_r(wstr,":",&stok_saveptr);
       pos=0;
       while (temp) {
 	add_path(config->font_search_path,temp,NULL,pos++);
 	temp=strtok_r(NULL,":",&stok_saveptr);
       }
+      free(wstr);
     break;
     
     case TTIP_TEXT:
@@ -1318,15 +1419,17 @@ static char *create_desktop_file_key(char *name) {
   char *key         = NULL;
   char *lc_messages = NULL; 
   char *lang        = NULL;
-  char *stok_saveptr;
+  char *stok_saveptr= NULL;
+  char *wstr;
   int  len;
 
   lc_messages=setlocale(LC_MESSAGES,NULL);
-  
+
   if ((!lc_messages) || (lc_messages[0]=='C')) {
     return NULL;
   }
   
+  
   /* lc_messages format is: lang_COUNTRY.ENCODING@MODIFIER.
    * 
    * application desktop files might includes severals locale
@@ -1335,7 +1438,8 @@ static char *create_desktop_file_key(char *name) {
    * get_locale_comment_key() get rid of country, encoding and
    * modifier informations.
    */
-  lang=strdup(strtok_r(lc_messages,"_",&stok_saveptr));
+  wstr=strdup(lc_messages);
+  lang=strdup(strtok_r(wstr,"_",&stok_saveptr));
     
   len=strlen(name)+strlen(lang)+2; /* +2 for the brackets [] */
   key=calloc(len+1,sizeof(char)); /* +1 for the null terminate byte */
@@ -1343,7 +1447,8 @@ static char *create_desktop_file_key(char *name) {
   strcat(key,"[");
   strcat(key,lang);
   strcat(key,"]");
-  
+
+  free(wstr);
   free(lang);
   
   return key;
@@ -1616,8 +1721,8 @@ void print_config() {
   fprintf(stdout,"tooltip-foreground-color     : %s\n",config->tooltip_fg_color);
   fprintf(stdout,"tooltip-border-size          : %d\n",config->tooltip_border_size);
   fprintf(stdout,"tooltip-text-padding         : %d\n",config->tooltip_text_padding);
-  fprintf(stdout,"tooltip-show_delay           : %d\n",config->tooltip_show_delay);
-  fprintf(stdout,"tooltip-hide_delay           : %d\n",config->tooltip_hide_delay);
+  fprintf(stdout,"tooltip-show-delay           : %d\n",config->tooltip_show_delay);
+  fprintf(stdout,"tooltip-hide-delay           : %d\n",config->tooltip_hide_delay);
   fprintf(stdout,"\n");
 
   fprintf(stdout,"icon-grayscale               : %d\n",config->icon_grayscale);
