@@ -631,7 +631,7 @@ int main(int argc, char *argv[])
   
   create_pixmaps();
 
-  if (config->tooltip_text) {
+  if ( (config->tooltip_text) && (config->tooltip_hide_delay>0) ) {
     create_tooltip_window(
       config->tooltip_text,
       config->tooltip_bg_color,
@@ -645,8 +645,8 @@ int main(int argc, char *argv[])
   display = get_display();
   x11fd   = get_connection();
   
-  /* Initializes the timers used to wait for events, to trigger the 
-   * tooltip, and to hide the tooltip. 
+  /* Initializes the timer used to wait for events, and, the timers to
+   * trigger and hide the tooltip if enabled.
    * 
    * Attention :
    *   1. the fields tv_sec & tv_usec must be initialized. Furthermore, 
@@ -660,15 +660,17 @@ int main(int argc, char *argv[])
    */
   wait_timer.tv_sec  = (WAIT_EVENT_TIMEOUT * 1000) / 1000000;
   wait_timer.tv_usec = (WAIT_EVENT_TIMEOUT * 1000) % 1000000;
+
+  if ( is_tooltip_enabled() ) {
+    show_ttip_timer.tv_sec  = (config->tooltip_show_delay * 1000) / 1000000;
+    show_ttip_timer.tv_usec = (config->tooltip_show_delay * 1000) % 1000000;
   
-  show_ttip_timer.tv_sec  = (config->tooltip_show_delay * 1000) / 1000000;
-  show_ttip_timer.tv_usec = (config->tooltip_show_delay * 1000) % 1000000;
+    hide_ttip_timer.tv_sec  = (config->tooltip_hide_delay * 1000) / 1000000;
+    hide_ttip_timer.tv_usec = (config->tooltip_hide_delay * 1000) % 1000000;
+  }
   
-  hide_ttip_timer.tv_sec  = (config->tooltip_hide_delay * 1000) / 1000000;
-  hide_ttip_timer.tv_usec = (config->tooltip_hide_delay * 1000) % 1000000;
-    
   while (handle_events) {
-    
+
     if (!XPending(display)) {
       /*
        * Waits events for at most X ms using a timer. If 
