@@ -269,7 +269,8 @@ _NLS_("%s <DELAY>\n\
 
   fprintf(stdout,
 _NLS_("%s <DELAY>\n\
-  Sets the tooltip hide timing delay to <DELAY> ms. Default to %d ms.\n\n"),
+  Sets the tooltip hide timing delay to <DELAY> ms. Default to %d ms. A value of \n\
+  0 disable the tooltip.\n\n"),
   get_option_name(TTIP_HIDE_DELAY,BOTH_NAMES,true,opt_name1,32),
   DEFAULT_TOOLTIP_HIDE_DELAY);
 
@@ -379,17 +380,20 @@ void print_fonts_info(char *extra_font_paths) {
   }
 
   if (extra_font_paths) {
-    char         *stok_saveptr;
+    char *wstr         = strdup(extra_font_paths);
+    char *stok_saveptr = NULL;
     
     t_path_list *path_list = new_path_list();
-    char         *cpath     = strtok_r(extra_font_paths,":",&stok_saveptr);
+    char         *cpath    = strtok_r(wstr,":",&stok_saveptr);
     int           pos=0;
     
     while (cpath) {
       add_path(path_list,cpath,NULL,pos++);
       cpath=strtok_r(NULL,":",&stok_saveptr);
     }
-    
+
+    free(wstr);
+
     add_font_path_to_imlib_path(path_list);
     free_path_list(path_list);
   }
