@@ -10,6 +10,7 @@
 #include <X11/Xlib.h>
 #include <X11/xpm.h>
 #include <wordexp.h>
+#include <glib.h>
 #include <librsvg/rsvg.h>
 #include <X11/extensions/shape.h>
 
@@ -173,7 +174,7 @@ static void clear_imlib_font_path() {
   while (count>0) {
     clen=strlen(path[0]);
     cpath=calloc(clen+1,sizeof(char));
-    strncpy(cpath,path[0],clen);
+    strcpy(cpath,path[0]);
 
     imlib_remove_path_from_font_path(cpath);
     free(cpath);
@@ -952,6 +953,7 @@ void hide_tooltip() {
  * instance. Returns NULL on error.
  */
 static Imlib_Image load_svg_image(char *filepath) {
+  GFile             *file       = g_file_new_for_path(filepath);
   RsvgHandle        *svg_handle = NULL;
   RsvgDimensionData  svg_dim;
   cairo_surface_t   *surface;
@@ -960,8 +962,13 @@ static Imlib_Image load_svg_image(char *filepath) {
   unsigned char    *svg_data = NULL;
   GError            *cairo_error = NULL;
   Imlib_Image       image;
+
+  if (!file) {
+    fprintf(stderr,_NLS_("Failed to load %s\n"),filepath);
+    return NULL;
+  }  
   
-  svg_handle=rsvg_handle_new_from_file(filepath,&cairo_error);
+  svg_handle=rsvg_handle_new_from_gfile_sync(file,RSVG_HANDLE_FLAGS_NONE,NULL,&cairo_error);
   
   if (!svg_handle) {
     fprintf(stderr,
@@ -1002,7 +1009,7 @@ static Imlib_Image load_svg_image(char *filepath) {
   cairo_surface_destroy(surface);    
   cairo_destroy(cairo);
 
-  rsvg_handle_close(svg_handle,&cairo_error);    
+  g_object_unref(file);
   g_object_unref(svg_handle);  
   
   return image;
